@@ -24,7 +24,7 @@ class NamedInputs:
 
         :see: https://nx.dev/reference/nx-json#inputs-&-namedinputs
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -55,9 +55,9 @@ class ProjectConfig:
         *,
         implicit_dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
         included_scripts: typing.Optional[typing.Sequence[builtins.str]] = None,
-        named_inputs: typing.Optional[typing.Union[NamedInputs, typing.Dict[str, typing.Any]]] = None,
+        named_inputs: typing.Optional[typing.Union[NamedInputs, typing.Dict[builtins.str, typing.Any]]] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-        targets: typing.Optional[typing.Mapping[builtins.str, typing.Union["ProjectTarget", typing.Dict[str, typing.Any]]]] = None,
+        targets: typing.Optional[typing.Mapping[builtins.str, typing.Union["ProjectTarget", typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param implicit_dependencies: Implicit dependencies.
@@ -69,22 +69,13 @@ class ProjectConfig:
         if isinstance(named_inputs, dict):
             named_inputs = NamedInputs(**named_inputs)
         if __debug__:
-            def stub(
-                *,
-                implicit_dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
-                included_scripts: typing.Optional[typing.Sequence[builtins.str]] = None,
-                named_inputs: typing.Optional[typing.Union[NamedInputs, typing.Dict[str, typing.Any]]] = None,
-                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-                targets: typing.Optional[typing.Mapping[builtins.str, typing.Union[ProjectTarget, typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__465cbd32966cf12b2a1ca4d4a9a82ffb07f0b488ad2ad310a2dd803c310135bd)
             check_type(argname="argument implicit_dependencies", value=implicit_dependencies, expected_type=type_hints["implicit_dependencies"])
             check_type(argname="argument included_scripts", value=included_scripts, expected_type=type_hints["included_scripts"])
             check_type(argname="argument named_inputs", value=named_inputs, expected_type=type_hints["named_inputs"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
             check_type(argname="argument targets", value=targets, expected_type=type_hints["targets"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if implicit_dependencies is not None:
             self._values["implicit_dependencies"] = implicit_dependencies
         if included_scripts is not None:
@@ -162,7 +153,7 @@ class ProjectTarget:
     def __init__(
         self,
         *,
-        depends_on: typing.Optional[typing.Sequence[typing.Union["TargetDependency", typing.Dict[str, typing.Any]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[typing.Union["TargetDependency", typing.Dict[builtins.str, typing.Any]]]] = None,
         inputs: typing.Optional[typing.Sequence[builtins.str]] = None,
         outputs: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
@@ -173,18 +164,11 @@ class ProjectTarget:
         :param outputs: List of outputs to cache, relative to the root of the monorepo. note: must start with leading /
         '''
         if __debug__:
-            def stub(
-                *,
-                depends_on: typing.Optional[typing.Sequence[typing.Union[TargetDependency, typing.Dict[str, typing.Any]]]] = None,
-                inputs: typing.Optional[typing.Sequence[builtins.str]] = None,
-                outputs: typing.Optional[typing.Sequence[builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__338709c2d2709d4d5924b0e892a7da42a86dea3a201ce56ef10b33fa1c78e0d7)
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
             check_type(argname="argument inputs", value=inputs, expected_type=type_hints["inputs"])
             check_type(argname="argument outputs", value=outputs, expected_type=type_hints["outputs"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if depends_on is not None:
             self._values["depends_on"] = depends_on
         if inputs is not None:
@@ -239,7 +223,7 @@ class TargetDefaults:
 
         :see: https://nx.dev/reference/nx-json#target-defaults
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -271,16 +255,10 @@ class TargetDependency:
         :param target: Projen target i.e: build, test, etc.
         '''
         if __debug__:
-            def stub(
-                *,
-                projects: TargetDependencyProject,
-                target: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6e52e3d9efe494a68d5a0d22a214d71c8a44be171424efcf89aca6047270df8a)
             check_type(argname="argument projects", value=projects, expected_type=type_hints["projects"])
             check_type(argname="argument target", value=target, expected_type=type_hints["target"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "projects": projects,
             "target": target,
         }
@@ -350,11 +328,11 @@ class WorkspaceConfig:
         affected_branch: typing.Optional[builtins.str] = None,
         cacheable_operations: typing.Optional[typing.Sequence[builtins.str]] = None,
         implicit_dependencies: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[builtins.str]]] = None,
-        named_inputs: typing.Optional[typing.Union[NamedInputs, typing.Dict[str, typing.Any]]] = None,
+        named_inputs: typing.Optional[typing.Union[NamedInputs, typing.Dict[builtins.str, typing.Any]]] = None,
         nx_cloud_read_only_access_token: typing.Optional[builtins.str] = None,
         nx_ignore: typing.Optional[typing.Sequence[builtins.str]] = None,
-        target_defaults: typing.Optional[typing.Union[TargetDefaults, typing.Dict[str, typing.Any]]] = None,
-        target_dependencies: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[TargetDependency, typing.Dict[str, typing.Any]]]]] = None,
+        target_defaults: typing.Optional[typing.Union[TargetDefaults, typing.Dict[builtins.str, typing.Any]]] = None,
+        target_dependencies: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[TargetDependency, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''NX workspace configurations.
 
@@ -374,19 +352,7 @@ class WorkspaceConfig:
         if isinstance(target_defaults, dict):
             target_defaults = TargetDefaults(**target_defaults)
         if __debug__:
-            def stub(
-                *,
-                affected_branch: typing.Optional[builtins.str] = None,
-                cacheable_operations: typing.Optional[typing.Sequence[builtins.str]] = None,
-                implicit_dependencies: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[builtins.str]]] = None,
-                named_inputs: typing.Optional[typing.Union[NamedInputs, typing.Dict[str, typing.Any]]] = None,
-                nx_cloud_read_only_access_token: typing.Optional[builtins.str] = None,
-                nx_ignore: typing.Optional[typing.Sequence[builtins.str]] = None,
-                target_defaults: typing.Optional[typing.Union[TargetDefaults, typing.Dict[str, typing.Any]]] = None,
-                target_dependencies: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[TargetDependency, typing.Dict[str, typing.Any]]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b5621333d7a417790081a88ae66edb9efb72f78d591ce7ca8add40d8274ecfda)
             check_type(argname="argument affected_branch", value=affected_branch, expected_type=type_hints["affected_branch"])
             check_type(argname="argument cacheable_operations", value=cacheable_operations, expected_type=type_hints["cacheable_operations"])
             check_type(argname="argument implicit_dependencies", value=implicit_dependencies, expected_type=type_hints["implicit_dependencies"])
@@ -395,7 +361,7 @@ class WorkspaceConfig:
             check_type(argname="argument nx_ignore", value=nx_ignore, expected_type=type_hints["nx_ignore"])
             check_type(argname="argument target_defaults", value=target_defaults, expected_type=type_hints["target_defaults"])
             check_type(argname="argument target_dependencies", value=target_dependencies, expected_type=type_hints["target_dependencies"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if affected_branch is not None:
             self._values["affected_branch"] = affected_branch
         if cacheable_operations is not None:
@@ -511,3 +477,45 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__465cbd32966cf12b2a1ca4d4a9a82ffb07f0b488ad2ad310a2dd803c310135bd(
+    *,
+    implicit_dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
+    included_scripts: typing.Optional[typing.Sequence[builtins.str]] = None,
+    named_inputs: typing.Optional[typing.Union[NamedInputs, typing.Dict[builtins.str, typing.Any]]] = None,
+    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+    targets: typing.Optional[typing.Mapping[builtins.str, typing.Union[ProjectTarget, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__338709c2d2709d4d5924b0e892a7da42a86dea3a201ce56ef10b33fa1c78e0d7(
+    *,
+    depends_on: typing.Optional[typing.Sequence[typing.Union[TargetDependency, typing.Dict[builtins.str, typing.Any]]]] = None,
+    inputs: typing.Optional[typing.Sequence[builtins.str]] = None,
+    outputs: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6e52e3d9efe494a68d5a0d22a214d71c8a44be171424efcf89aca6047270df8a(
+    *,
+    projects: TargetDependencyProject,
+    target: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b5621333d7a417790081a88ae66edb9efb72f78d591ce7ca8add40d8274ecfda(
+    *,
+    affected_branch: typing.Optional[builtins.str] = None,
+    cacheable_operations: typing.Optional[typing.Sequence[builtins.str]] = None,
+    implicit_dependencies: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[builtins.str]]] = None,
+    named_inputs: typing.Optional[typing.Union[NamedInputs, typing.Dict[builtins.str, typing.Any]]] = None,
+    nx_cloud_read_only_access_token: typing.Optional[builtins.str] = None,
+    nx_ignore: typing.Optional[typing.Sequence[builtins.str]] = None,
+    target_defaults: typing.Optional[typing.Union[TargetDefaults, typing.Dict[builtins.str, typing.Any]]] = None,
+    target_dependencies: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[TargetDependency, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
